@@ -6,12 +6,14 @@ from decimal import Decimal
 
 import pytz
 from django.db.models import Q
+from django.forms import model_to_dict
 from django.utils import timezone
 from django.utils.datetime_safe import datetime
 from rest_framework import serializers
 
 from xj_user.models import BaseInfo, Platform
 from xj_user.services.user_platform_service import UserPlatformService
+from xj_user.services.user_service import UserService
 
 from ..utils.jt import Jt
 from ..models import Transact, Currency, PayMode, SandBox
@@ -67,6 +69,7 @@ class FinanceTransactSerializer(serializers.ModelSerializer):
             'their_account_id',
             'their_account_name',
             'platform_id',
+            'enroll_id',
             'order_no',
             'opposite_account',
             'summary',
@@ -228,9 +231,9 @@ class FinanceTransactService:
         their_account_id = param.get('their_account_id', '')
         # print("> their_account_id:", their_account_id, )
         # 如果有id需要判断是否为数字
-        if their_account_id and not their_account_id.isdecimal():
-            # return Response({'err': 1004, 'msg': '用户their_account_id必须是数字', })
-            return None, '用户their_account_id必须是数字'
+        # if their_account_id and not their_account_id.isdecimal():
+        #     # return Response({'err': 1004, 'msg': '用户their_account_id必须是数字', })
+        #     return None, '用户their_account_id必须是数字'
         if their_account_id:
             their_account_id = int(their_account_id)
         if their_account_id:
@@ -258,7 +261,6 @@ class FinanceTransactService:
             transact_id = param.get('transact_id', '')
 
         item['transact_id'] = transact_id
-
         # print(">>> transact_id:", transact_id)
         if is_create and Transact.objects.filter(transact_id=transact_id).values().count():
             # return Response({'err': 1007, 'msg': '新增时发现复重交易ID，请检查是否有重复记录: ' + transact_id, })
@@ -266,13 +268,17 @@ class FinanceTransactService:
         if not is_create and Transact.objects.filter(transact_id=transact_id).values().count() == 0:
             # return Response({'err': 1008, 'msg': '修改信息的交易ID不存在: ' + transact_id, })
             return None, '修改信息的交易ID不存在: ' + transact_id
-
+        tz = pytz.timezone('Asia/Shanghai')
+        # 返回datetime格式的时间
+        now_time = timezone.now().astimezone(tz=tz).strftime("%Y-%m-%d %H:%M:%S")
+        now = datetime.strptime(now_time, '%Y-%m-%d %H:%M:%S')
         # 如果没有时间则生成交易时间
         # transact_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
         transact_time = param.get('transact_time', '')
         # print(">>> transact_time:", transact_time, )
+        # if transact_time else timezone.localtime() if is_create TODO USE_TZ = False 时会报错 如果USE_TZ设置为True时，Django会使用系统默认设置的时区，即America/Chicago，此时的TIME_ZONE不管有没有设置都不起作用。
         item['transact_time'] = datetime.strptime(transact_time, '%Y-%m-%d %H:%M:%S') \
-            if transact_time else timezone.localtime() if is_create \
+            if transact_time else now if is_create \
             else Transact.objects.filter(transact_id=transact_id).first().transact_time
         # print(">>> transact_time:", transact_time, item['transact_time'], type(item['transact_time']))
         if not item['transact_time']:
@@ -314,6 +320,9 @@ class FinanceTransactService:
         # print(">>> income:", income)
         # print(">>> outgo:", outgo)
 
+        enroll_id = param.get('enroll_id', '')
+        if enroll_id:
+            item['enroll_id'] = enroll_id
         # 沙盒 ----------------------------------------------------------------------
         sand_box_name = param.get('sand_box', '')
         if sand_box_name:
@@ -330,6 +339,7 @@ class FinanceTransactService:
         balance_set = Transact.objects.filter(
             Q(account_id=account_id) &
             Q(currency_id=item['currency']) &
+            Q(platform_id=item['platform_id']) &
             Q(transact_time__lt=item['transact_time']) &
             ~Q(transact_id=item['transact_id'])
         )
@@ -351,9 +361,12 @@ class FinanceTransactService:
         # is_inside_pay = True if pay_mode.upper() == 'BALANCE' else False
         # print(">>> is_inside_pay:", is_inside_pay)
         # balance = last_balance + income - (outgo if is_inside_pay else Decimal(0.0))
-        balance = last_balance + income - outgo
-        # print(">>> balance:", balance)
-        item['balance'] = balance
+
+        item['balance'] = last_balance
+        if pay_mode == "BALANCE":
+            balance = last_balance + income - outgo
+            # print(">>> balance:", balance)
+            item['balance'] = balance
         # if balance < 0:
         #     return Response({'err': 1014, 'msg': '余额不足，待扣金额为'+str(amount)+'，当前余额为'+str(last_balance)+',差额'+str(balance) })
 
@@ -401,32 +414,28 @@ class FinanceTransactService:
                 # return Response({'err': 1015, 'msg': '重复的交易订单号：' + str(order_no), })
                 return None, '重复的交易订单号：' + str(order_no)
         # --------------------------------------------------------------------------------------
+
         if not param.get('their_account_id', '') and not param.get('their_account_name', ''):
             # return Response({'err': 1016, 'msg': 'their_account_id或their_account_name 必填', })
             return None, 'their_account_id或their_account_name 必填'
         # 没有对方账户ID时从对方账户名创建一个账户
         # 如果无their_account_id、有their_account_name，则用their_account_name生成一个their_account_id
+        # TODO 貌似该功能不能使用 作废
         if not param.get('their_account_id', '') and param.get('their_account_name', ''):
             their_account_name = param['their_account_name']
-            platform_id = BaseInfo.objects.get(id=account_id).platform_id
-
-            new_user_param = {
-                "platform_id": platform_id,
-                "full_name": their_account_name,
-                "platform_uid": str(int(time.time())) + FinanceTransactService.random_four_int(),  # 这样写好吗？
-            }
-            # 增加一个用户
-            user_serializer = UserSerializer(data=new_user_param, context={})
-            # print(">>> user_serializer ", user_serializer)
-            if not user_serializer.is_valid():
-                # return Response({'err': 1017, 'msg': user_serializer.errors, })
-                return None, user_serializer.errors
-            user_serializer.validated_data['platform_id'] = platform_id
-            # print(">>> user_serializer.validated_data['platform_id']", user_serializer.validated_data['platform_id'])
-            user_serializer.save()
-            # 这是什么写法？传递引用了两次呢
-            item['their_account_id'] = BaseInfo.objects.get(platform_uid=new_user_param['platform_uid']).id
-            item['their_account'] = BaseInfo.objects.get(id=item['their_account_id'])
+            base_info = BaseInfo.objects.filter(nickname=their_account_name).first()
+            if base_info:
+                base_info = model_to_dict(base_info)
+                item['their_account_id'] = base_info['id']
+                item['their_account'] = BaseInfo.objects.get(id=item['their_account_id'])
+            else:
+                new_user_param = {
+                    "full_name": their_account_name,
+                    "nickname": their_account_name,
+                }
+                new_user = BaseInfo.objects.create(**new_user_param)
+                item['their_account_id'] = new_user.id
+                item['their_account'] = BaseInfo.objects.get(id=item['their_account_id'])
         # -------------------------------------------------------------------------------------
 
         # 如果有id，则是修改数据
@@ -434,7 +443,7 @@ class FinanceTransactService:
             response = FinanceTransactService.create(item)
         else:
             response = FinanceTransactService.update(item)
-
+        # return None
         return response
 
     # 增
@@ -454,6 +463,7 @@ class FinanceTransactService:
         # 验证成功，获取数据
         serializer.validated_data['platform_id'] = item['platform_id']
         serializer.validated_data['account'] = item['account']
+        serializer.validated_data['enroll_id'] = item['enroll_id']
         serializer.validated_data['their_account'] = item['their_account']
         serializer.validated_data['pay_mode'] = item['pay_mode_set']
         serializer.validated_data['currency'] = item['currency_set']
@@ -494,6 +504,7 @@ class FinanceTransactService:
         # 验证成功，获取数据
         update_serializer.validated_data['platform_id'] = item['platform_id']
         update_serializer.validated_data['account'] = item['account']
+        update_serializer.validated_data['enroll_id'] = item['enroll_id']
         update_serializer.validated_data['their_account'] = item['their_account']
         update_serializer.validated_data['pay_mode'] = item['pay_mode_set']
         update_serializer.validated_data['currency'] = item['currency_set']
