@@ -1,22 +1,13 @@
-import math
-import random
-import time
-import os
 from decimal import Decimal
+import random
 
 import pytz
-from django.db.models import Q
-from django.utils import timezone
-from django.utils.datetime_safe import datetime
 from rest_framework import serializers
-from django.db.models import Q, F
-from django.db.models import Sum, Count
-from xj_user.models import BaseInfo, Platform
-from xj_user.services.user_platform_service import UserPlatformService
 
-from ..utils.jt import Jt
-from ..models import Transact, Currency, PayMode, SandBox
+from xj_enroll.utils.custom_tool import format_params_handle
+from xj_user.models import BaseInfo
 from .finance_service import FinanceService
+from ..models import Transact
 
 
 # 声明用户序列化
@@ -51,6 +42,7 @@ class FinanceTransactsSerializer(serializers.ModelSerializer):
     # platform = serializers.ReadOnlyField(source='platform.platform_name')
     pay_mode = serializers.ReadOnlyField(source='pay_mode.pay_mode')
     currency = serializers.ReadOnlyField(source='currency.currency')
+
     # income = serializers.ReadOnlyField(source='income')
     # outgo = serializers.ReadOnlyField(source='outgo')
 
@@ -115,7 +107,6 @@ class FinanceTransactsSerializer(serializers.ModelSerializer):
     #     return int(obj.transact_time.timestamp())
 
 
-
 class FinanceTransactsService:
     @staticmethod
     def get(params, user_id):
@@ -145,7 +136,6 @@ class FinanceTransactsService:
 
         # ========== 四、相关前置业务逻辑处理 ==========
 
-
         # ========== 五、翻页 ==========
 
         page = int(params['page']) - 1 if 'page' in params else 0
@@ -166,7 +156,7 @@ class FinanceTransactsService:
 
         # return {'total': total, 'list': res_list, 'statistics': statistic_list}, None
 
-        return {'size': int(size), 'page': int(page+1), 'total': total, 'list': res_list}, None
+        return {'size': int(size), 'page': int(page + 1), 'total': total, 'list': res_list}, None
 
         # return {'total': total, 'list': res_list}, None
         # 翻译
@@ -187,3 +177,33 @@ class FinanceTransactsService:
             ch = chr(random.randrange(ord('0'), ord('9') + 1))
             str += ch
         return str
+
+    @staticmethod
+    def detail(pk=None, order_no=None, transact_id=None, field_list=None):
+        """
+        查询订单性情
+        """
+        if not pk and not order_no and not transact_id:
+            return None, None
+
+        transact_obj = Transact.objects
+
+        if pk:
+            transact_filter_obj = transact_obj.filter(id=pk).first()
+        elif order_no:
+            transact_filter_obj = transact_obj.filter(order_no=order_no).first()
+        elif transact_id:
+            transact_filter_obj = transact_obj.filter(transact_id=transact_id).first()
+        else:
+            return None, "没有找到对应的数据"
+
+        if not transact_filter_obj:
+            return None, "没有找到对应的数据"
+
+        transact_dict = transact_filter_obj.to_json()
+
+        transact_filter_dict = format_params_handle(
+            param_dict=transact_dict,
+            filter_filed_list=field_list
+        )
+        return transact_filter_dict, None
