@@ -1,9 +1,8 @@
-#_*_coding:utf-8_*_
+# _*_coding:utf-8_*_
 from django.urls import re_path
 from django.conf.urls import static
 from django.conf import settings
 
-
 from .apis.finance_transacts import FinanceTransacts
 from .apis.finance_transact import FinanceTransact
 from .apis.finance_pay_mode import FinancePayMode
@@ -13,7 +12,7 @@ from .apis.finance_currency import FinanceCurrency
 from .apis.finance_sand_box import FinanceSandBox
 from .apis.finance_contact_book import UserContactBook
 from .apis.finance_statistic import FinanceStatistic
-
+from .apis.finance_balance import FinanceBalance
 
 urlpatterns = [
     re_path(r'^transacts/?$', FinanceTransacts.as_view(), ),
@@ -26,6 +25,7 @@ urlpatterns = [
     re_path(r'^contact_book/?$', UserContactBook.as_view(), ),
     # re_path(r'^_export/?$', ExportExcel.as_view(), ),
     re_path(r'^statistic/?$', FinanceStatistic.as_view(), ),
+    re_path(r'^balance/?$', FinanceBalance.as_view(), ),
 
     # 该功能已使用finance_transact的POST方法代替
     # re_path(r'^_transact_add/?$', finance_transact_add.FinanceTransactAdd.as_view(), ),
@@ -44,5 +44,3 @@ urlpatterns = [
     #     "media"
     # ),
 ]
-
-
